@@ -16,7 +16,7 @@ def spark_setup():
   clear_output()
   print('Updating system configurations.')
   pbar.update(1)
-  run_bash_command('apt-get install openjdk-8-jdk-headless -qq > /dev/null')
+  run_bash_command('apt-get install openjdk-8-jdk-headless -qq')
   clear_output()
   print('Downloading spark-2.4.8-bin-hadoop2.')
   pbar.update(1)
